==> ejc-salary-api-3.0.0-20240920.090714-5-sources.jar: com/ejianc/business/salary/vo/RosterTransferVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-异动
 * 
 * @author generator
 * 
 */
public class RosterTransferVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private Date startTime; // 起始时间
    private Date endTime; // 终止时间
    private String orgCode; // 所在单位code
    private String orgName; // 所在单位
    private String departmentCode; // 所在部门code
    private String departmentName; // 所在部门
    private String projectCode; // 所在项目code
    private String projectName; // 所在项目
    private String postCode; // 任职岗位code
    private String postName; // 任职岗位
    private Long syncDay; // 同步日期
    private String hrId; // 人力主键
    private Integer hrState; // 人力状态（1：正常，2：删除）
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-api-3.0.0-20241017.075358-34-sources.jar: com/ejianc/business/salary/vo/RosterTransferVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人员花名册-异动
 * 
 * @author generator
 * 
 */
public class RosterTransferVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startTime; // 起始时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime; // 终止时间
    private String orgCode; // 所在单位code
    private String orgName; // 所在单位
    private String departmentCode; // 所在部门code
    private String departmentName; // 所在部门
    private String projectCode; // 所在项目code
    private String projectName; // 所在项目
    private String postCode; // 任职岗位code
    private String postName; // 任职岗位
    private Long syncDay; // 同步日期
    private String hrId; // 人力主键
    private Integer hrState; // 人力状态（1：正常，2：删除）
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getDepartmentCode() {
        return departmentCode;
    }

    public void setDepartmentCode(String departmentCode) {
        this.departmentCode = departmentCode;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getPostCode() {
        return postCode;
    }

    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public Long getSyncDay() {
        return syncDay;
    }

    public void setSyncDay(Long syncDay) {
        this.syncDay = syncDay;
    }
    public String getHrId() {
        return hrId;
    }

    public void setHrId(String hrId) {
        this.hrId = hrId;
    }
    public Integer getHrState() {
        return hrState;
    }

    public void setHrState(Integer hrState) {
        this.hrState = hrState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
